# -*- coding: utf-8 -*-
# type: ignore
# pylint: disable=all
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: location.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0elocation.proto"\xc5\x02\n\x08Response\x12%\n\x05wifis\x18\x02 \x03(\x0b\x32\x16.Response.ResponseWifi\x1a\x91\x02\n\x0cResponseWifi\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x35\n\x08location\x18\x02 \x01(\x0b\x32#.Response.ResponseWifi.WifiLocation\x12\x0f\n\x07\x63hannel\x18\x15 \x01(\x05\x1a\xab\x01\n\x0cWifiLocation\x12\x10\n\x08latitude\x18\x01 \x01(\x03\x12\x11\n\tlongitude\x18\x02 \x01(\x03\x12\x10\n\x08\x61\x63\x63uracy\x18\x03 \x01(\x05\x12\x12\n\nzeroField4\x18\x04 \x01(\x05\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x05\x12\x18\n\x10\x61ltitudeAccuracy\x18\x06 \x01(\x05\x12\x11\n\tunknown11\x18\x0b \x01(\x05\x12\x11\n\tunknown12\x18\x0c \x01(\x05"\x81\x01\n\x07Request\x12#\n\x05wifis\x18\x02 \x03(\x0b\x32\x14.Request.RequestWifi\x12\x10\n\x05noise\x18\x03 \x01(\x05:\x01\x30\x12\x13\n\x06signal\x18\x04 \x01(\x05:\x03\x31\x30\x30\x12\x0e\n\x06source\x18\x05 \x01(\t\x1a\x1a\n\x0bRequestWifi\x12\x0b\n\x03mac\x18\x01 \x01(\t'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "location_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_RESPONSE"]._serialized_start = 19
    _globals["_RESPONSE"]._serialized_end = 344
    _globals["_RESPONSE_RESPONSEWIFI"]._serialized_start = 71
    _globals["_RESPONSE_RESPONSEWIFI"]._serialized_end = 344
    _globals["_RESPONSE_RESPONSEWIFI_WIFILOCATION"]._serialized_start = 173
    _globals["_RESPONSE_RESPONSEWIFI_WIFILOCATION"]._serialized_end = 344
    _globals["_REQUEST"]._serialized_start = 347
    _globals["_REQUEST"]._serialized_end = 476
    _globals["_REQUEST_REQUESTWIFI"]._serialized_start = 450
    _globals["_REQUEST_REQUESTWIFI"]._serialized_end = 476
# @@protoc_insertion_point(module_scope)
